/*
    Copyright (C) 2000  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston,
    MA 02111-1307, USA.
*/

extern void xawm_free_colors(void);
extern void xawm_alloc_color(Display *, Colormap, XColor *);
extern void xawm_query_color(Display *, Colormap, XColor *);
extern GC _XawAllocFgGC(Widget, Pixel, Font);
extern GC _XawAllocGreyGC(Widget, Pixel, Font, int, int);
extern Status _XawAllocGrayPixel(Widget, Pixel, int, Pixel *);
