/* $Id: XawAlloc.h,v 1.2 2000/10/12 14:55:21 ulric Exp $ */

#define	XtStackAlloc(size, stack_cache_array)	\
    ((size) <= sizeof(stack_cache_array)	\
    ? (XtPointer)(stack_cache_array)		\
    : XtMalloc((unsigned)(size)))

#define	XtStackFree(pointer, stack_cache_array)	\
    if ((pointer) != ((XtPointer)(stack_cache_array))) XtFree(pointer); else

